==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Enabled" : "Bật",
    "Saved" : "Đã lưu",
    "Authentication error" : "Lỗi xác thực",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Email saved" : "Lưu email",
    "Couldn't update app." : "Không thể cập nhật ứng dụng",
    "Email sent" : "Email đã được gửi",
    "All" : "Tất cả",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Delete" : "Xóa",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "never" : "không thay đổi",
    "__language_name__" : "Tiếng Việt",
    "Unlimited" : "Không giới hạn",
    "None" : "Không gì cả",
    "Login" : "Đăng nhập",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Cron" : "Cron",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Version" : "Phiên bản",
    "Sharing" : "Chia sẻ",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Forum" : "Diễn đàn",
    "Upload new" : "Tải lên",
    "Remove image" : "Xóa ",
    "Cancel" : "Hủy",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Password" : "Mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Language" : "Ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "Name" : "Tên",
    "Username" : "Tên đăng nhập",
    "Create" : "Tạo",
    "Other" : "Khác",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "Unable to add user to group %s" : "Không thể thêm người dùng vào nhóm %s",
    "Unable to remove user from group %s" : "Không thể xóa người dùng từ nhóm %s",
    "Cheers!" : "Chúc mừng!"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Saved" : "Đã lưu",
    "Authentication error" : "Lỗi xác thực",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Email saved" : "Lưu email",
    "Couldn't update app." : "Không thể cập nhật ứng dụng",
    "Email sent" : "Email đã được gửi",
    "All" : "Tất cả",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Delete" : "Xóa",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "never" : "không thay đổi",
    "Forum" : "Diễn đàn",
    "None" : "Không gì cả",
    "Login" : "Đăng nhập",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Version" : "Phiên bản",
    "Sharing" : "Chia sẻ",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Upload new" : "Tải lên",
    "Remove image" : "Xóa ",
    "Cancel" : "Hủy",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Language" : "Ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "Password" : "Mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Username" : "Tên đăng nhập",
    "Create" : "Tạo",
    "Unlimited" : "Không giới hạn",
    "Other" : "Khác",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định",
    "Enabled" : "Bật",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "Unable to add user to group %s" : "Không thể thêm người dùng vào nhóm %s",
    "Unable to remove user from group %s" : "Không thể xóa người dùng từ nhóm %s",
    "__language_name__" : "Tiếng Việt",
    "Cron" : "Cron",
    "Cheers!" : "Chúc mừng!",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "Name" : "Tên"
},
"nplurals=1; plural=0;");
